////////////////////////////////////////////////////////////////
//
// Copyright (C) 2006 Affymetrix, Inc.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License (version 2) as
// published by the Free Software Foundation.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program;if not, write to the
//
// Free Software Foundation, Inc.,
// 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
//
////////////////////////////////////////////////////////////////

/**
 * @file   matrix-diff-test.cpp
 * @brief  Program for doing regression tests on matrix-diff.
 */

#include "util/RegressionTest.h"

using namespace std;

class MatrixDiffTest
{

public:
  int numPassed, numFailed;
  MatrixDiffTest()
  {
    numPassed = 0;
    numFailed = 0;
  }
  void testNumericDifferences();
  void testMixedDifferences();
};

void MatrixDiffTest::testNumericDifferences()
{
  string command = "./apt-matrix-diff -l 1 -e 0.1 data/test-numeric-gold.txt data/test-numeric-generated.txt";
  vector<RegressionCheck *> checks;
  RegressionTest differencesTest (command.c_str(), checks);
  Verbose::out (1, "\nDoing testNumericDifferences()");
  if (differencesTest.run())
    ++numPassed;
  else
  {
    Verbose::out (1, "Error in MatrixDiffTest::testNumericDifferences(): " + differencesTest.getErrorMsg());
    ++numFailed;
  }
}

void MatrixDiffTest::testMixedDifferences()
{
  string command = "./apt-matrix-diff -mixed -l 10 -p data/test-mixed-gold.txt data/test-mixed-generated.txt";
  vector<RegressionCheck *> checks;
  RegressionTest differencesTest (command.c_str(), checks);
  Verbose::out (1, "Doing testMixedDifferences()");
  if (differencesTest.run())
    ++numPassed;
  else
  {
    Verbose::out (1, "Error in MatrixDiffTest::testMixedDifferences(): " + differencesTest.getErrorMsg());
    ++numFailed;
  }
}

int main (int argc, char* argv[])
{
  MatrixDiffTest test;
  Verbose::setLevel(2);
  Verbose::progressBegin (1, "Doing tests", 20, 1, 20);
  test.testNumericDifferences();
  test.testMixedDifferences();
  Verbose::progressEnd (1, "Done.");
  Verbose::out (1, "NumPassed: " + ToStr (test.numPassed) + " NumFailed: " + ToStr (test.numFailed));
  return test.numFailed != 0;
}
